#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='savings',
      version='0.0.1',
      description='Module documentation here...',
      author=None,
      author_email='OV <olav.vahtras@gmail.com>',
      url=None,
      py_modules=['savings'],
     )
